The ``linchpin`` CLI is used to perform tasks related to managing :term:`resources`. We'll cover the basics of how to use ``linchpin``. For greater detail, see :doc:`../cli`.

Getting Help
````````````

.. include:: includes/cli_help.rst

.. _basic_usage:

Basic Usage
```````````

.. include:: includes/cli_basic_usage.rst

.. _options:

Options and Arguments
`````````````````````

.. include:: includes/cli_opts_args.rst

.. _combining_options:



